MyEasyDurationInt extension
Return Duration base on int input
ex: 1.seconds -> Duration(seconds: 1);
- on
Properties
- day → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Return current int in Duration of daysno setter - dd → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Short-hand for daysno setter - hr → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Short-hand for hoursno setter - micSec → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Short-hand for microsecondsno setter - miliseconds → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Return current int in Duration of milisecondsno setter - milSec → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Short-hand for milisecondsno setter - min → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Short-hand for minutesno setter - mm → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Short-hand for monthsno setter - months → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Return current int in Duration of month (30 days / month)no setter - sec → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Short-hand for secondsno setter - weeks → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Return current int in Duration of weeks (7 days/ week)no setter - wk → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Short-hand for weeksno setter - years → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Return current int in Duration of years (356 days/ year)no setter - yy → Duration
-
Available on int, provided by the MyEasyDurationInt extension
Short-hand for yearsno setter
Methods
-
circles(
Duration circleLength) → Duration -
Available on int, provided by the MyEasyDurationInt extension
Return current int in Duration of circles (You decide circle length) -
convertToMonthString(
) → String -
Available on int, provided by the MyEasyDurationInt extension